@@ -1,7 +1,7 @@
 """
 :Author: dongyu
 :Date: 2020-04-11 18:44:08
-:LastEditTime: 2021-01-12 08:35:36
+:LastEditTime: 2021-06-29 11:57:10
 :LastEditors: HuangJingCan
 :Description: 菜单相关类
 """
@@ -52,10 +52,16 @@ class PowerMenuTreeHandler(StudioBaseHandler):
         is_super = self.get_is_super()
         curr_user_id = self.request_user_id()
         product_id = self.request_product_id()
+        # 是否权限无限下放（0-无限等级，1-下放一级）
+        power_grade = int(config.get_value("power_grade", 0))
 
         power_model = PowerModel(manage_context_key, is_super, curr_user_id, product_id)
         result = power_model.get_menu_item_tree()
 
+        # 非超管则无权限下放功能，没有用户和角色添加权限
+        if not is_super and power_grade > 0:
+            result = [i for i in result if i['MenuID'] != config.get_value("menu_id_platform")]
+
         self.reponse_json_success(result)
 
 
