@@ -1,7 +1,7 @@
 """
 :Author: wang kui
 :Date: 2020-03-24 16:32:52
-:LastEditTime: 2021-01-12 08:36:35
+:LastEditTime: 2021-06-29 18:38:33
 :LastEditors: HuangJingCan
 :Description: power 用户权限相关接口
 """
@@ -34,6 +34,8 @@ class GetUserInfoHandler(StudioBaseHandler):
         user_info = self.get_curr_user_info()
         curr_info = {}
         if user_info:
+            curr_info["Account"] = user_info.Account
+            curr_info["IsSuper"] = user_info.IsSuper
             curr_info["NickName"] = user_info.NickName
             curr_info["Avatar"] = user_info.Avatar
             curr_info["Phone"] = user_info.Phone
