@@ -2,7 +2,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-29 11:00:52
-:LastEditTime: 2022-05-24 18:24:43
+:LastEditTime: 2022-05-24 20:42:21
 :LastEditors: ChenXiaolei
 :Description: 文件上传信息
 """
@@ -87,7 +87,7 @@ class FileUpload():
         file_upload_info = FileUploadInfo()
         file_extension = os.path.splitext(file_name)[1]
         if file_restrict.FileExtension != "":
-            file_find = file_restrict.FileExtension.find(file_extension.strip("."))
+            file_find = file_restrict.FileExtension.find(file_extension.lower().strip("."))
             if file_find == -1:
                 invoke_result.ResultCode = "1"
                 invoke_result.ResultMessage = f"上传的文件扩展名必须是{file_restrict.FileExtension}，当前文件是:{file_extension}"
