@@ -1,7 +1,7 @@
 """
 :Author: HuangJingCan
 :Date: 2020-04-15 09:56:24
-:LastEditTime: 2021-06-30 19:19:11
+:LastEditTime: 2021-06-30 19:46:55
 :LastEditors: HuangJingCan
 :Description: 权限角色栏目相关
 """
@@ -315,7 +315,7 @@ class PowerModel():
 
             cote_id = curr_menu_info.MenuID + "$"
             for dr in menu_cote_table:
-                if self.__check_menu_power(self.is_super, curr_menu_info.MenuID, dr[menu_cote.IDName]):
+                if not self.__check_menu_power(self.is_super, curr_menu_info.MenuID, dr[menu_cote.IDName]):
                     continue
                 cote_menu_info = MenuInfo()
                 cote_menu_info.MenuID = cote_id + str(dr[menu_cote.IDName])
